Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(576)

Unified Diff: components/security_interstitials/content/unsafe_resource.cc

Issue 2905343002: Show interstitial on a password on focus ping with PHISHING verdict. (Closed)
Patch Set: nit Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/security_interstitials/content/unsafe_resource.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/security_interstitials/content/unsafe_resource.cc
diff --git a/components/security_interstitials/content/unsafe_resource.cc b/components/security_interstitials/content/unsafe_resource.cc
index c6204cb9652b7d30a783c483da2a2a146b2aa25a..e8dd7012f43938a9e1a841af664e92d061e466d1 100644
--- a/components/security_interstitials/content/unsafe_resource.cc
+++ b/components/security_interstitials/content/unsafe_resource.cc
@@ -40,10 +40,13 @@ bool UnsafeResource::IsMainPageLoadBlocked() const {
if (is_subresource)
return false;
// Client-side phishing detection interstitials never block the main frame
// load, since they happen after the page is finished loading.
if (threat_type == safe_browsing::SB_THREAT_TYPE_CLIENT_SIDE_PHISHING_URL ||
- threat_type == safe_browsing::SB_THREAT_TYPE_CLIENT_SIDE_MALWARE_URL) {
+ threat_type == safe_browsing::SB_THREAT_TYPE_CLIENT_SIDE_MALWARE_URL ||
+ threat_type ==
+ safe_browsing::SB_THREAT_TYPE_PASSWORD_PROTECTION_PHISHING_URL) {
return false;
}
« no previous file with comments | « components/security_interstitials/content/unsafe_resource.h ('k') | no next file » | no next file with comments »
@@ -40,10 +40,13 @@ bool UnsafeResource::IsMainPageLoadBlocked() const {
if (is_subresource)
return false;
- // Client-side phishing detection interstitials never block the main frame
- // load, since they happen after the page is finished loading.
+ // Client-side phishing/malware detection and password protection phishing
+ // interstitials never block the main frame load, since they happen after the
+ // page is finished loading.
if (threat_type == safe_browsing::SB_THREAT_TYPE_CLIENT_SIDE_PHISHING_URL ||

Powered by Google App Engine
This is Rietveld 408576698